@@ -22,9 +22,8 @@ class tag(base):
         if tagid:
             data["tagid"] = tagid
         api_name = "tag/create"
-        response = self.request(
-            api_name=api_name, method="post", json=data)
-        logger.debug(response)
+        response = self.request(api_name=api_name, method="post", json=data)
+        
         return response
 
     def update(self, tagid: int, tagname: str) -> dict:
@@ -38,23 +37,16 @@ class tag(base):
             dict: 
         """
         api_name = "tag/update"
-        data = {
-            "tagid": tagid,
-            "tagname": tagname
-        }
-        response = self.request(
-            api_name=api_name, method="post", json=data)
-        logger.debug(response)
+        data = {"tagid": tagid, "tagname": tagname}
+        response = self.request(api_name=api_name, method="post", json=data)
+        
         return response
 
     def delete(self, tagid: int):
         api_name = "tag/delete"
-        params = {
-            "tagid": tagid
-        }
-        response = self.request(
-            api_name=api_name, method="get", params=params)
-        logger.debug(response)
+        params = {"tagid": tagid}
+        response = self.request(api_name=api_name, method="get", params=params)
+        
         return response
 
     def get(self, tagid: int):
@@ -64,15 +56,14 @@ class tag(base):
             tagid (int): 标签ID
         """
         api_name = "tag/get"
-        params = {
-            "tagid": tagid
-        }
-        response = self.request(
-            api_name=api_name, method="get", params=params)
-        logger.debug(response)
+        params = {"tagid": tagid}
+        response = self.request(api_name=api_name, method="get", params=params)
+        
         return response
 
-    def addtagusers(self, tagid: int, userlist: list = [], partylist: list = []) -> dict:
+    def addtagusers(
+        self, tagid: int, userlist: list = [], partylist: list = []
+    ) -> dict:
         """增加标签成员
 
         Args:
@@ -91,12 +82,13 @@ class tag(base):
             data["userlist"] = userlist
         if partylist:
             data["partylist"] = partylist
-        response = self.request(
-            api_name=api_name, method="post", json=data)
-        logger.debug(response)
+        response = self.request(api_name=api_name, method="post", json=data)
+        
         return response
 
-    def deltagusers(self, tagid: int, userlist: list = [], partylist: list = []) -> dict:
+    def deltagusers(
+        self, tagid: int, userlist: list = [], partylist: list = []
+    ) -> dict:
         """删除标签成员
 
         Args:
@@ -115,14 +107,12 @@ class tag(base):
             data["userlist"] = userlist
         if partylist:
             data["partylist"] = partylist
-        response = self.request(
-            api_name=api_name, method="post", json=data)
-        logger.debug(response)
+        response = self.request(api_name=api_name, method="post", json=data)
+        
         return response
 
     def list(self):
         api_name = "tag/list"
-        response = self.request(
-            api_name=api_name, method="get")
-        logger.debug(response)
+        response = self.request(api_name=api_name, method="get")
+        
         return response
